#include "KFont.h"

#include "KTexture.h"

namespace KapitanGame
{
	KFont::KFont()
		= default;

	KFont::~KFont()
	{
		Free();
	}

	KFont::KFont(KFont&& other) noexcept : Font(other.Font)
	{
		other.Font = nullptr;
	}

	KFont& KFont::operator=(KFont&& other) noexcept
	{
		Font = other.Font;
		other.Font = nullptr;
		return *this;
	}

	bool KFont::LoadFromFile(const std::string& path, const int ptSize)
	{
		bool success = true;
		Font = TTF_OpenFont(path.c_str(), ptSize);
		if (Font == nullptr)
		{
			printf("Failed to load %s font! SDL_ttf Error: %s\n", path.c_str(), TTF_GetError());
			success = false;
		}
		return success;
	}

	void KFont::Free()
	{
		if (Font != nullptr)
		{
			TTF_CloseFont(Font);
			Font = nullptr;
		}
	}

	KTexture KFont::GetTextTexture(const std::string& text, const SDL_Color textColor, SDL_Renderer* renderer) const
	{
		KTexture texture;
		SDL_Surface* textSurface = TTF_RenderText_Blended(Font, text.c_str(), textColor);
		if (textSurface == nullptr)
		{
			printf("Unable to render text surface! SDL_ttf Error: %s\n", TTF_GetError());
		}
		else
		{
			texture.LoadFromSurface(textSurface, renderer);
			SDL_FreeSurface(textSurface);
		}
		return texture;
	}
}
