#include "KPawn.h"

#include <memory>
#include <typeinfo>

#include "Constants.h"
#include "KPlayerController.h"
#include "KExit.h"

namespace KapitanGame
{
	void KPawn::CollisionDetectionStep(const std::vector<std::shared_ptr<KObject>>& objects)
	{
		if (GetCollider() == nullptr) return;
		for (auto& other : objects) {
			if (other->GetCollider() == nullptr) continue;
			if (other->Id == Id) continue;
			if (GetCollider()->IsCollision(other->GetCollider())) {
				if (typeid(*other) == typeid(KExit)) {
					if (const auto pc = PlayerController.lock()) {
						pc->NotifyWin();
					}
					return;
				}
				const auto separationVector = GetCollider()->GetSeparationVector(other->GetCollider());
				Position += separationVector;
			}
		}
	}

	void KPawn::MovementStep(const float& timeStep)
	{
		Position += Velocity * timeStep;
	}

	void KPawn::CollisionDetectionWithMapStep(const SDL_FRect& map)
	{
		Position += GetCollider()->GetSeparationVector(map);
	}

	void KPawn::AddMovementInput(const KVector2D& input)
	{
		Velocity = input * Constants::SPEED * (1 - Constants::SMOOTH) + Velocity * Constants::SMOOTH;
	}
}

